==> haskell-exceptions-0.10.1-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: exceptions
version: 0.10.1
id: exceptions-0.10.1-7EeRXpdm0c5D9yRsXefkxH
key: exceptions-0.10.1-7EeRXpdm0c5D9yRsXefkxH
license: BSD-3-Clause
copyright: Copyright (C) 2013-2015 Edward A. Kmett
           Copyright (C) 2012 Google Inc.
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/exceptions/
synopsis: Extensible optionally-pure exceptions
description:
    Extensible optionally-pure exceptions.
category: Control, Exceptions, Monad
abi: fefc2e75f30882f96d0dffa6eea508e0
exposed: True
exposed-modules:
    Control.Monad.Catch Control.Monad.Catch.Pure
import-dirs: /usr/lib/ghc-8.6.5/site-local/exceptions-0.10.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/exceptions-0.10.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/exceptions-0.10.1
hs-libraries: HSexceptions-0.10.1-7EeRXpdm0c5D9yRsXefkxH
depends:
    base-4.12.0.0 mtl-2.2.2 stm-2.5.0.0 template-haskell-2.14.0.0
    transformers-0.5.6.2
    transformers-compat-0.6.4-3mIoeQKAFq789cuQC8bUpt
haddock-interfaces: /usr/share/doc/haskell-exceptions/html/exceptions.haddock
haddock-html: /usr/share/doc/haskell-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-exceptions-0.10.2-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: exceptions
version: 0.10.2
id: exceptions-0.10.2-6GSxCzaG9kmCGyegXlyMgA
key: exceptions-0.10.2-6GSxCzaG9kmCGyegXlyMgA
license: BSD-3-Clause
copyright: Copyright (C) 2013-2015 Edward A. Kmett
           Copyright (C) 2012 Google Inc.
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/exceptions/
synopsis: Extensible optionally-pure exceptions
description:
    Extensible optionally-pure exceptions.
category: Control, Exceptions, Monad
abi: eb0e84b8296288b28a9af4ade01782be
exposed: True
exposed-modules:
    Control.Monad.Catch Control.Monad.Catch.Pure
import-dirs: /usr/lib/ghc-8.6.5/site-local/exceptions-0.10.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/exceptions-0.10.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/exceptions-0.10.2
hs-libraries: HSexceptions-0.10.2-6GSxCzaG9kmCGyegXlyMgA
depends:
    base-4.12.0.0 mtl-2.2.2 stm-2.5.0.0 template-haskell-2.14.0.0
    transformers-0.5.6.2
    transformers-compat-0.6.4-3mIoeQKAFq789cuQC8bUpt
haddock-interfaces: /usr/share/doc/haskell-exceptions/html/exceptions.haddock
haddock-html: /usr/share/doc/haskell-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
